@@ -7,8 +7,7 @@
 
 (* Delete the given subtree of the given replica                             *)
 val delete :
-     bool                        (* keep backup? *)
-  -> Common.root                 (* source root *)
+     Common.root                 (* source root *)
   -> Path.t                      (* deleted path *)
   -> Common.root                 (* root *)
   -> Path.t                      (* path to delete *)
@@ -19,8 +18,7 @@ val delete :
 (* is performed atomically (or as close to atomically as the os will         *)
 (* support) using temporary files.                                           *)
 val copy :
-     bool                       (* save old version? *)
-  -> [`Update of (Uutil.Filesize.t * Uutil.Filesize.t) | `Copy]
+     [`Update of (Uutil.Filesize.t * Uutil.Filesize.t) | `Copy]
                                 (* whether there was already a file *)
   -> Common.root                (* from what root *)
   -> Path.t                     (* from what path *)
@@ -62,6 +60,8 @@ val diff :
 (* terminated) synchronizations                                              *)
 val processCommitLogs : unit -> unit
 
+val makeSureMergeTempfilesAreIgnored : unit -> unit
+
 (* List the files in a directory matching a pattern.  (It would be better
    to use fspath, etc., here instead of string) *)
 val ls : string -> string -> string list
@@ -69,13 +69,14 @@ val ls : string -> string -> string list
 val get_files_in_directory : string -> string list
 
 val merge :
-     Common.root                (* first root *)
-  -> Common.root                (* second root *)
-  -> Path.t                     (* path to merge *)
-  -> Uutil.File.t               (* id for showing progress of transfer *)
-  -> Common.updateItem          (* differences from the archive *)
-  -> Common.updateItem          (* ... *)
-  -> (string->string->bool)     (* function to display the (title and) result and ask user for confirmation
-                                   (when -batch is true, the function should not ask any questions and should
-                                   always return true) *)
+     Common.root                  (* first root *)
+  -> Common.root                  (* second root *)
+  -> Path.t                       (* path to merge *)
+  -> Uutil.File.t                 (* id for showing progress of transfer *)
+  -> Common.updateItem            (* differences from the archive *)
+  -> Common.updateItem            (* ... *)
+  -> (bool->string->string->bool) (* function to display the (title and) result 
+				     and ask user for confirmation (when -batch 
+				     is true, the function should not ask any 
+				     questions and should always return true) *)
   -> unit
