@@ -58,6 +58,7 @@ let installRoots termInteract =
 
 (* Alternate interface, should replace old interface eventually *)
 let installRoots2 () =
+  debug (fun () -> Util.msg "Installing roots...");
   let roots = rawRoots () in
   theroots :=
     Safelist.map Remote.canonize ((Safelist.map Clroot.parseRoot) roots);
@@ -181,7 +182,7 @@ let propagatePrefsTo =
   Remote.registerHostCmd
     "installPrefs"
     (fun prefs -> return (Prefs.load prefs))
-
+    
 let propagatePrefs () =
   let prefs = Prefs.dump() in
   let toHost root =
@@ -209,7 +210,8 @@ let ignore =
      ^ "children).  This is useful for avoiding synchronizing temporary "
      ^ "files, object files, etc. The syntax of \\ARG{pathspec} is "
      ^ "described in \\sectionref{pathspec}{Path Specification}, and further "
-     ^ "details on ignoring paths is found in \\sectionref{ignore}{Ignoring Paths}.")
+     ^ "details on ignoring paths is found in"
+     ^ " \\sectionref{ignore}{Ignoring Paths}.")
     
 let ignorenot =
   Pred.create "ignorenot"
@@ -265,38 +267,3 @@ let mergeCmdForPath p =
   else
     try Pred.assoc merge (Path.toString p)
     with Not_found -> Pred.assoc mergebatch (Path.toString p)
-
-let backup =
-   Pred.create "backup"
-   ("Including the preference \\texttt{-backup \\ARG{pathspec}} "
-   ^ "causes Unison to make back up for each path that matches "
-   ^ "\\ARG{pathspec}.  More precisely, for each path that "
-   ^ "matches this \\ARG{pathspec}, "
-   ^ "Unison will keep several old versions of a file as a backup whenever "
-   ^ "a change is propagated.  These backup files are left in the "
-   ^ "directory specified by the environment variable {\\tt UNISONBACKUPDIR}, "
-    ^ "if it is set; otherwise in the directory named by the {\\tt backupdir} "
-    ^ "preference, if it is non-null; otherwise in "
-   ^ " \\verb|.unison/backup/| by default.  The newest backed up copy will"
-   ^ "have the same name as the original; older versions will be named "
-   ^ "with extensions \\verb|.n.unibck|."
-   ^ " The number of versions that are kept is determined by the "
-   ^ "\\verb|maxbackups| preference."
-   ^ "\n\n The syntax of \\ARG{pathspec} is described in \\sectionref{pathspec}{Path Specification}.")
-
-let _ = Pred.alias backup "mirror"
-
-let backupnot =
-   Pred.create "backupnot"
-   ("The values of this preference specify paths or individual files or"
-    ^ " regular expressions that should {\\em not} "
-    ^ "be backed up, even if the {\\tt backup} preference selects "
-    ^ "them---i.e., "
-    ^ "it selectively overrides {\\tt backup}.  The same caveats apply here "
-    ^ "as with {\\tt ignore} and {\tt ignorenot}.")
-
-let shouldBackup p =
-  let s = (Path.toString p) in
-  (Pred.test backup s && not (Pred.test backupnot s))
-
-    
