@@ -655,21 +655,17 @@ let getSecondRoot () =
       `Local ->
         Clroot.clroot2string(Clroot.ConnectLocal(Some file))
     | `SSH | `RSH ->
-        let portOpt =
-          (* FIX: report an error if the port entry is not well formed *)
-          try Some(int_of_string(portE#text))
-          with _ -> None in
         Clroot.clroot2string(
         Clroot.ConnectByShell((if !varLocalRemote=`SSH then "ssh" else "rsh"),
                               host,
                               (if user="" then None else Some user),
-                              portOpt,
+                              Some portE#text,
                               Some file))
     | `SOCKET ->
         Clroot.clroot2string(
         (* FIX: report an error if the port entry is not well formed *)
         Clroot.ConnectBySocket(host,
-                               int_of_string(portE#text),
+                               portE#text,
                                Some file)) in
   let contCommand() =
     try
@@ -1611,7 +1607,8 @@ in
                   catch (fun () ->
                            Transport.transportItem
                              theSI.ri (Uutil.File.ofLine i)
-                             (fun title text -> Trace.status (Printf.sprintf "\n%s\n\n%s\n\n" title text); true)
+                             (fun proceed title text -> 
+			       Trace.status (Printf.sprintf "\n%s\n\n%s\n\n" title text); proceed)
                            >>= (fun () ->
                            return Util.Succeeded))
                         (fun e ->
