@@ -40,7 +40,7 @@ val updateArchive :
 (* Replace a part of an archive by another archive *)
 val replaceArchive :
   Common.root -> Path.t -> (Fspath.t * Path.local) option ->
-  archive -> transaction -> Path.local Lwt.t
+  archive -> transaction -> bool -> Path.local Lwt.t
 (* Update only some permissions *)
 val updateProps :
   Common.root -> Path.t -> Props.t option -> Common.updateItem ->
@@ -67,23 +67,6 @@ val unlockArchives : unit -> unit Lwt.t
 val translatePath : Common.root -> Path.t -> Path.local Lwt.t
 val translatePathLocal : Fspath.t -> Path.t -> Path.local
 
-(* Find the fspath for the backup file corresponding to a given path in the
-   local replica *)
-val findBackup : Path.local -> Fspath.t option
-
-(*
-(* Where is the backup directory *)
-(* FIX: This should not be exported *)
-val backupDirectory : unit -> Fspath.t
-*)
-
-(* Back up a file that is about to be overwritten *)
-val makeBackupFile :
-  Common.root ->
-  Fspath.t -> Path.local -> (* Which file we should mirror *)
-  Path.local ->             (* Its location with respect to the replica root *)
-  unit Lwt.t
-
 (* Are we checking fast, or carefully? *)
 val fastcheck : string Prefs.t
 
